@@ -1,9 +1,6 @@
 package JIRA::Client;
-{
-  $JIRA::Client::VERSION = '0.42';
-}
-# ABSTRACT: Extended interface to JIRA's SOAP API
-
+# ABSTRACT: (DEPRECATED) Extended interface to JIRA's SOAP API
+$JIRA::Client::VERSION = '0.44';
 use strict;
 use warnings;
 
@@ -675,7 +672,21 @@ sub filter_issues_unsorted {
 
     if ($filter =~ /^(?:[A-Z]+-\d+\s+)*[A-Z]+-\d+$/i) {
         # space separated key list
-        return map {$self->getIssue(uc $_)} split / /, $filter;
+
+        # Let's construct a JQL query in the form "issuekey IN (...)" to
+        # pass to getIssuesFromJqlSearch.
+
+        my %keys = map {($_ => undef)} split / /, $filter; # discard duplicates
+        my @keys = keys %keys;
+
+        # If the list is too big we split it up and invoke
+        # getIssuesFromJqlSearch several times.
+        my @issues;
+        while (my @subkeys = splice(@keys, 0, 128)) {
+            my $jql = 'issuekey IN (' . join(',', @subkeys) . ')';
+            push @issues, @{$self->getIssuesFromJqlSearch($jql, 1000)};
+        }
+        return @issues;
     } elsif ($filter =~ /^[\w-]+$/i) {
         # saved filter
         return @{$self->getIssuesFromFilterWithLimit($filter, 0, $limit || 1000)};
@@ -702,10 +713,7 @@ sub filter_issues {
 ## no critic (Modules::ProhibitMultiplePackages)
 
 package RemoteFieldValue;
-{
-  $RemoteFieldValue::VERSION = '0.42';
-}
-
+$RemoteFieldValue::VERSION = '0.44';
 sub new {
     my ($class, $id, $values) = @_;
 
@@ -718,10 +726,7 @@ sub new {
 
 
 package RemoteCustomFieldValue;
-{
-  $RemoteCustomFieldValue::VERSION = '0.42';
-}
-
+$RemoteCustomFieldValue::VERSION = '0.44';
 sub new {
     my ($class, $id, $values) = @_;
 
@@ -731,10 +736,7 @@ sub new {
 
 
 package RemoteComponent;
-{
-  $RemoteComponent::VERSION = '0.42';
-}
-
+$RemoteComponent::VERSION = '0.44';
 sub new {
     my ($class, $id, $name) = @_;
     my $o = bless({id => $id}, $class);
@@ -744,10 +746,7 @@ sub new {
 
 
 package RemoteVersion;
-{
-  $RemoteVersion::VERSION = '0.42';
-}
-
+$RemoteVersion::VERSION = '0.44';
 sub new {
     my ($class, $id, $name) = @_;
     my $o = bless({id => $id}, $class);
@@ -989,11 +988,11 @@ __END__
 
 =head1 NAME
 
-JIRA::Client - Extended interface to JIRA's SOAP API
+JIRA::Client - (DEPRECATED) Extended interface to JIRA's SOAP API
 
 =head1 VERSION
 
-version 0.42
+version 0.44
 
 =head1 SYNOPSIS
 
@@ -1023,13 +1022,13 @@ version 0.42
 
 =head1 DESCRIPTION
 
-JIRA is a proprietary bug tracking system from Atlassian
-(L<http://www.atlassian.com/software/jira/>).
-
 B<DEPRECATION WARNING>: Please, before using this module consider using the
 newer L<JIRA::REST> because JIRA's SOAP API was
-L<deprecated|https://developer.atlassian.com/display/JIRADEV/SOAP+and+XML-RPC+API+Deprecated+in+JIRA+6.0>
-on JIRA 6.0 and won't be available anymore on JIRA 7.0.
+L<deprecated|https://developer.atlassian.com/jiradev/latest-updates/soap-and-xml-rpc-api-deprecation-notice>
+on JIRA 6.0 and isn't available anymore on JIRA 7.0.
+
+JIRA is a proprietary bug tracking system from Atlassian
+(L<http://www.atlassian.com/software/jira/>).
 
 This module implements an Object Oriented wrapper around JIRA's SOAP
 API, which is specified in
@@ -1419,6 +1418,10 @@ to getIssue. For example:
 
     KEY-123 chave-234 CLAVE-345
 
+Note that the result list doesn't respect the order in which the keys are
+specified and also that duplicate keys are discarded and the corresponding
+issue appear only once in the resulting list.
+
 =item The name of a saved filter
 
 If FILTER is a single word, it is passed to
@@ -1506,13 +1509,17 @@ distribution.
 
 =back
 
+=head1 REPOSITORY
+
+L<https://github.com/gnustavo/JIRA-Client>
+
 =head1 AUTHOR
 
 Gustavo L. de M. Chaves <gnustavo@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by CPqD.
+This software is copyright (c) 2016 by CPqD.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
